@@ -202,138 +202,240 @@ class WrappingKeySpec(str):
 
 
 class AlreadyExistsException(ServiceException):
+    code: str = "AlreadyExistsException"
+    sender_fault: bool = False
+    status_code: int = 400
     message: Optional[ErrorMessageType]
 
 
 class CloudHsmClusterInUseException(ServiceException):
+    code: str = "CloudHsmClusterInUseException"
+    sender_fault: bool = False
+    status_code: int = 400
     message: Optional[ErrorMessageType]
 
 
 class CloudHsmClusterInvalidConfigurationException(ServiceException):
+    code: str = "CloudHsmClusterInvalidConfigurationException"
+    sender_fault: bool = False
+    status_code: int = 400
     message: Optional[ErrorMessageType]
 
 
 class CloudHsmClusterNotActiveException(ServiceException):
+    code: str = "CloudHsmClusterNotActiveException"
+    sender_fault: bool = False
+    status_code: int = 400
     message: Optional[ErrorMessageType]
 
 
 class CloudHsmClusterNotFoundException(ServiceException):
+    code: str = "CloudHsmClusterNotFoundException"
+    sender_fault: bool = False
+    status_code: int = 400
     message: Optional[ErrorMessageType]
 
 
 class CloudHsmClusterNotRelatedException(ServiceException):
+    code: str = "CloudHsmClusterNotRelatedException"
+    sender_fault: bool = False
+    status_code: int = 400
     message: Optional[ErrorMessageType]
 
 
 class CustomKeyStoreHasCMKsException(ServiceException):
+    code: str = "CustomKeyStoreHasCMKsException"
+    sender_fault: bool = False
+    status_code: int = 400
     message: Optional[ErrorMessageType]
 
 
 class CustomKeyStoreInvalidStateException(ServiceException):
+    code: str = "CustomKeyStoreInvalidStateException"
+    sender_fault: bool = False
+    status_code: int = 400
     message: Optional[ErrorMessageType]
 
 
 class CustomKeyStoreNameInUseException(ServiceException):
+    code: str = "CustomKeyStoreNameInUseException"
+    sender_fault: bool = False
+    status_code: int = 400
     message: Optional[ErrorMessageType]
 
 
 class CustomKeyStoreNotFoundException(ServiceException):
+    code: str = "CustomKeyStoreNotFoundException"
+    sender_fault: bool = False
+    status_code: int = 400
     message: Optional[ErrorMessageType]
 
 
 class DependencyTimeoutException(ServiceException):
+    code: str = "DependencyTimeoutException"
+    sender_fault: bool = False
+    status_code: int = 400
     message: Optional[ErrorMessageType]
 
 
 class DisabledException(ServiceException):
+    code: str = "DisabledException"
+    sender_fault: bool = False
+    status_code: int = 400
     message: Optional[ErrorMessageType]
 
 
 class ExpiredImportTokenException(ServiceException):
+    code: str = "ExpiredImportTokenException"
+    sender_fault: bool = False
+    status_code: int = 400
     message: Optional[ErrorMessageType]
 
 
 class IncorrectKeyException(ServiceException):
+    code: str = "IncorrectKeyException"
+    sender_fault: bool = False
+    status_code: int = 400
     message: Optional[ErrorMessageType]
 
 
 class IncorrectKeyMaterialException(ServiceException):
+    code: str = "IncorrectKeyMaterialException"
+    sender_fault: bool = False
+    status_code: int = 400
     message: Optional[ErrorMessageType]
 
 
 class IncorrectTrustAnchorException(ServiceException):
+    code: str = "IncorrectTrustAnchorException"
+    sender_fault: bool = False
+    status_code: int = 400
     message: Optional[ErrorMessageType]
 
 
 class InvalidAliasNameException(ServiceException):
+    code: str = "InvalidAliasNameException"
+    sender_fault: bool = False
+    status_code: int = 400
     message: Optional[ErrorMessageType]
 
 
 class InvalidArnException(ServiceException):
+    code: str = "InvalidArnException"
+    sender_fault: bool = False
+    status_code: int = 400
     message: Optional[ErrorMessageType]
 
 
 class InvalidCiphertextException(ServiceException):
+    code: str = "InvalidCiphertextException"
+    sender_fault: bool = False
+    status_code: int = 400
     message: Optional[ErrorMessageType]
 
 
 class InvalidGrantIdException(ServiceException):
+    code: str = "InvalidGrantIdException"
+    sender_fault: bool = False
+    status_code: int = 400
     message: Optional[ErrorMessageType]
 
 
 class InvalidGrantTokenException(ServiceException):
+    code: str = "InvalidGrantTokenException"
+    sender_fault: bool = False
+    status_code: int = 400
     message: Optional[ErrorMessageType]
 
 
 class InvalidImportTokenException(ServiceException):
+    code: str = "InvalidImportTokenException"
+    sender_fault: bool = False
+    status_code: int = 400
     message: Optional[ErrorMessageType]
 
 
 class InvalidKeyUsageException(ServiceException):
+    code: str = "InvalidKeyUsageException"
+    sender_fault: bool = False
+    status_code: int = 400
     message: Optional[ErrorMessageType]
 
 
 class InvalidMarkerException(ServiceException):
+    code: str = "InvalidMarkerException"
+    sender_fault: bool = False
+    status_code: int = 400
     message: Optional[ErrorMessageType]
 
 
 class KMSInternalException(ServiceException):
+    code: str = "KMSInternalException"
+    sender_fault: bool = False
+    status_code: int = 400
     message: Optional[ErrorMessageType]
 
 
 class KMSInvalidMacException(ServiceException):
+    code: str = "KMSInvalidMacException"
+    sender_fault: bool = False
+    status_code: int = 400
     message: Optional[ErrorMessageType]
 
 
 class KMSInvalidSignatureException(ServiceException):
+    code: str = "KMSInvalidSignatureException"
+    sender_fault: bool = False
+    status_code: int = 400
     message: Optional[ErrorMessageType]
 
 
 class KMSInvalidStateException(ServiceException):
+    code: str = "KMSInvalidStateException"
+    sender_fault: bool = False
+    status_code: int = 400
     message: Optional[ErrorMessageType]
 
 
 class KeyUnavailableException(ServiceException):
+    code: str = "KeyUnavailableException"
+    sender_fault: bool = False
+    status_code: int = 400
     message: Optional[ErrorMessageType]
 
 
 class LimitExceededException(ServiceException):
+    code: str = "LimitExceededException"
+    sender_fault: bool = False
+    status_code: int = 400
     message: Optional[ErrorMessageType]
 
 
 class MalformedPolicyDocumentException(ServiceException):
+    code: str = "MalformedPolicyDocumentException"
+    sender_fault: bool = False
+    status_code: int = 400
     message: Optional[ErrorMessageType]
 
 
 class NotFoundException(ServiceException):
+    code: str = "NotFoundException"
+    sender_fault: bool = False
+    status_code: int = 400
     message: Optional[ErrorMessageType]
 
 
 class TagException(ServiceException):
+    code: str = "TagException"
+    sender_fault: bool = False
+    status_code: int = 400
     message: Optional[ErrorMessageType]
 
 
 class UnsupportedOperationException(ServiceException):
+    code: str = "UnsupportedOperationException"
+    sender_fault: bool = False
+    status_code: int = 400
     message: Optional[ErrorMessageType]
 
 
