@@ -12,8 +12,7 @@ from apispec import APISpec
 from botocore.utils import InvalidArnException
 from jsonpatch import apply_patch
 from jsonpointer import JsonPointerException
-from moto.apigateway import models as apigateway_models
-from moto.apigateway.models import Authorizer
+from moto.apigateway.models import Authorizer, Integration, Resource, RestAPI, apigateway_backends
 from moto.apigateway.utils import create_id as create_resource_id
 from requests.models import Response
 
@@ -218,9 +217,7 @@ def get_stage_variables(context: ApiInvocationContext) -> Optional[Dict[str, str
         return {}
 
     region_name = [
-        name
-        for name, region in apigateway_models.apigateway_backends.items()
-        if context.api_id in region.apis
+        name for name, region in apigateway_backends.items() if context.api_id in region.apis
     ][0]
     api_gateway_client = aws_stack.connect_to_service("apigateway", region_name=region_name)
     try:
@@ -397,7 +394,7 @@ def extract_path_params(path: str, extracted_path: str) -> Dict[str, str]:
     return path_params
 
 
-def extract_query_string_params(path: str) -> Tuple[str, Dict[str, str]]:
+def extract_query_string_params(path: str) -> list[str, Dict[str, str]]:
     parsed_path = urlparse.urlparse(path)
     path = parsed_path.path
     parsed_query_string_params = urlparse.parse_qs(parsed_path.query)
@@ -589,9 +586,7 @@ def apply_json_patch_safe(subject, patch_operations, in_place=True, return_list=
     return (results or [subject])[-1]
 
 
-def import_api_from_openapi_spec(
-    rest_api: apigateway_models.RestAPI, body: Dict, query_params: Dict
-) -> apigateway_models.RestAPI:
+def import_api_from_openapi_spec(rest_api: RestAPI, body: Dict, query_params: Dict) -> RestAPI:
     """Import an API from an OpenAPI spec document"""
 
     resolved_schema = resolve_references(body)
@@ -613,36 +608,38 @@ def import_api_from_openapi_spec(
         security_schemes = path_payload.get("security")
         for security_scheme in security_schemes:
             for security_scheme_name, _ in security_scheme.items():
-                if security_scheme_name in body.get("securityDefinitions"):
+                if security_scheme_name in body.get("securityDefinitions", []):
                     security_config = body.get("securityDefinitions", {}).get(security_scheme_name)
                     aws_apigateway_authorizer = security_config.get(
-                        "x-amazon-apigateway-authorizer"
+                        "x-amazon-apigateway-authorizer", {}
                     )
+                    if not aws_apigateway_authorizer:
+                        continue
+
                     if authorizers.get(security_scheme_name):
                         return authorizers.get(security_scheme_name)
-                    else:
-                        authorizer = rest_api.create_authorizer(
-                            create_resource_id(),
-                            name=security_scheme_name,
-                            authorizer_type=aws_apigateway_authorizer.get("type"),
-                            provider_arns=None,
-                            auth_type=security_config.get("x-amazon-apigateway-authtype"),
-                            authorizer_uri=aws_apigateway_authorizer.get("authorizerUri"),
-                            authorizer_credentials=aws_apigateway_authorizer.get(
-                                "authorizerCredentials"
-                            ),
-                            identity_source=aws_apigateway_authorizer.get("identitySource"),
-                            identiy_validation_expression=aws_apigateway_authorizer.get(
-                                "identityValidationExpression"
-                            ),
-                            authorizer_result_ttl=aws_apigateway_authorizer.get(
-                                "authorizerResultTtlInSeconds"
-                            )
-                            or 300,
+                    authorizer = rest_api.create_authorizer(
+                        create_resource_id(),
+                        name=security_scheme_name,
+                        authorizer_type=aws_apigateway_authorizer.get("type"),
+                        provider_arns=None,
+                        auth_type=security_config.get("x-amazon-apigateway-authtype"),
+                        authorizer_uri=aws_apigateway_authorizer.get("authorizerUri"),
+                        authorizer_credentials=aws_apigateway_authorizer.get(
+                            "authorizerCredentials"
+                        ),
+                        identity_source=aws_apigateway_authorizer.get("identitySource"),
+                        identiy_validation_expression=aws_apigateway_authorizer.get(
+                            "identityValidationExpression"
+                        ),
+                        authorizer_result_ttl=aws_apigateway_authorizer.get(
+                            "authorizerResultTtlInSeconds"
                         )
-                        if authorizer:
-                            authorizers.update({security_scheme_name: authorizer})
-                        return authorizer
+                        or 300,
+                    )
+                    if authorizer:
+                        authorizers.update({security_scheme_name: authorizer})
+                    return authorizer
 
     def get_or_create_path(path):
         parts = path.rstrip("/").replace("//", "/").split("/")
@@ -662,7 +659,7 @@ def import_api_from_openapi_spec(
     def add_path(path, parts, parent_id=""):
         child_id = create_resource_id()
         path = path or "/"
-        resource = apigateway_models.Resource(
+        resource = Resource(
             resource_id=child_id,
             region_name=rest_api.region_name,
             api_id=rest_api.id,
@@ -692,19 +689,23 @@ def import_api_from_openapi_spec(
                     response_model,
                     response_parameters,
                 )
-            integration = apigateway_models.Integration(
+
+            integration = Integration(
                 http_method=method,
                 uri=method_integration.get("uri"),
-                integration_type=method_integration["type"],
+                integration_type=method_integration.get("type"),
                 passthrough_behavior=method_integration.get("passthroughBehavior"),
                 request_templates=method_integration.get("requestTemplates") or {},
+                request_parameters=method_integration.get("requestParameters") or {},
             )
             integration.create_integration_response(
-                status_code=method_integration.get("default", {}).get("statusCode", 200),
+                status_code=method_integration.get("responses", {})
+                .get("default", {})
+                .get("statusCode", 200),
                 selection_pattern=None,
-                response_templates=method_integration.get("default", {}).get(
-                    "responseTemplates", None
-                ),
+                response_templates=method_integration.get("responses", {})
+                .get("default", {})
+                .get("responseTemplates", None),
                 content_handling=None,
             )
             resource.resource_methods[method]["methodIntegration"] = integration
@@ -894,6 +895,22 @@ def extract_api_id_from_hostname_in_url(hostname: str) -> str:
     return match.group(1)
 
 
+# This need to be extended to handle mappings and not just literal values.
+def create_invocation_headers(invocation_context: ApiInvocationContext) -> Dict[str, Any]:
+    headers = invocation_context.headers
+    integration = invocation_context.integration
+
+    if request_parameters := integration.get("requestParameters"):
+        for req_parameter_key, req_parameter_value in request_parameters.items():
+            if (
+                header_name := req_parameter_key.lstrip("integration.request.header.")
+                if "integration.request.header." in req_parameter_key
+                else None
+            ):
+                headers.update({header_name: req_parameter_value})
+    return headers
+
+
 # TODO:
 # - handle extensions
 #
