@@ -33,7 +33,6 @@ from localstack.services.awslambda.lambda_utils import (
     store_lambda_logs,
 )
 from localstack.services.install import GO_LAMBDA_RUNTIME, INSTALL_PATH_LOCALSTACK_FAT_JAR
-from localstack.utils import bootstrap
 from localstack.utils.aws import aws_stack
 from localstack.utils.aws.aws_models import LambdaFunction
 from localstack.utils.aws.dead_letter_queue import (
@@ -41,6 +40,7 @@ from localstack.utils.aws.dead_letter_queue import (
     sqs_error_to_dead_letter_queue,
 )
 from localstack.utils.cloudwatch.cloudwatch_util import cloudwatched
+from localstack.utils.collections import select_attributes
 from localstack.utils.common import (
     TMP_FILES,
     CaptureOutput,
@@ -65,6 +65,7 @@ from localstack.utils.common import (
     truncate,
     wait_for_port_open,
 )
+from localstack.utils.container_networking import get_main_container_name
 from localstack.utils.container_utils.container_client import (
     ContainerConfiguration,
     ContainerException,
@@ -108,6 +109,9 @@ LAMBDA_CONCURRENCY_LOCK = {}
 # CWD folder of handler code in Lambda containers
 DOCKER_TASK_FOLDER = "/var/task"
 
+# TODO remove once clarification of apigateway contexts is complete. Really bad hack!!
+ALLOWED_IDENTITY_FIELDS = ["cognitoIdentityId", "cognitoIdentityPoolId"]
+
 # Lambda event type
 LambdaEvent = Union[Dict[str, Any], str, bytes]
 
@@ -141,11 +145,13 @@ class LambdaContext:
         self.invoked_function_arn = lambda_function.arn()
         if qualifier:
             self.invoked_function_arn += ":" + qualifier
-        self.cognito_identity = context.get("identity")
+        self.cognito_identity = context.get("identity") and select_attributes(
+            context.get("identity"), ALLOWED_IDENTITY_FIELDS
+        )
         self.aws_request_id = str(uuid.uuid4())
         self.memory_limit_in_mb = lambda_function.memory_size or self.DEFAULT_MEMORY_LIMIT
-        self.log_group_name = "/aws/lambda/%s" % self.function_name
-        self.log_stream_name = "%s/[1]%s" % (timestamp(format="%Y/%m/%d"), short_uid())
+        self.log_group_name = f"/aws/lambda/{self.function_name}"
+        self.log_stream_name = f"{timestamp(format='%Y/%m/%d')}/[1]{short_uid()}"
 
     def get_remaining_time_in_millis(self):
         # TODO implement!
@@ -903,6 +909,7 @@ class LambdaExecutorReuseContainers(LambdaExecutorContainers):
             self.start_idle_container_destroyer_interval()
 
     def cleanup(self, arn: str = None):
+        LOG.debug("Cleaning up docker-reuse executor. Set arn: %s", arn)
         if arn:
             self.function_invoke_times.pop(arn, None)
             return self.destroy_docker_container(arn)
@@ -1091,6 +1098,7 @@ class LambdaExecutorReuseContainers(LambdaExecutorContainers):
         Stops and/or removes all lambda docker containers for localstack.
         :return: None
         """
+        LOG.debug("Destroying all running docker-reuse lambda containers")
         with self.docker_container_lock:
             container_names = self.get_all_container_names()
 
@@ -1165,7 +1173,7 @@ class LambdaExecutorReuseContainers(LambdaExecutorContainers):
         Returns the prefix of all docker-reuse lambda containers for this LocalStack instance
         :return: Lambda container name prefix
         """
-        return f"{bootstrap.get_main_container_name()}_lambda_"
+        return f"{get_main_container_name()}_lambda_"
 
     def get_container_name(self, func_arn):
         """
@@ -1590,11 +1598,8 @@ class Util:
             )
         docker_tag = runtime
         docker_image = config.LAMBDA_CONTAINER_REGISTRY
-        if runtime == "nodejs14.x" and docker_image == DEFAULT_LAMBDA_CONTAINER_REGISTRY:
-            # TODO temporary fix until lambci image for nodejs14.x becomes available
-            docker_image = "localstack/lambda-js"
-        elif (
-            runtime in ["python3.9", "dotnet6"]
+        if (
+            runtime in ["nodejs14.x", "nodejs16.x", "python3.9", "dotnet6"]
             and docker_image == DEFAULT_LAMBDA_CONTAINER_REGISTRY
         ):
             # TODO temporary fix until we support AWS images via https://github.com/localstack/localstack/pull/4734
