@@ -15,6 +15,7 @@ from pathlib import Path
 from typing import Callable, Dict, List, Tuple
 
 import requests
+import semver
 from plugin import Plugin, PluginManager
 
 from localstack import config
@@ -27,9 +28,11 @@ from localstack.constants import (
     ELASTICSEARCH_DELETE_MODULES,
     ELASTICSEARCH_PLUGIN_LIST,
     KMS_URL_PATTERN,
+    LIBSQLITE_AARCH64_URL,
     LOCALSTACK_MAVEN_VERSION,
     MODULE_MAIN_PATH,
     OPENSEARCH_DEFAULT_VERSION,
+    OPENSEARCH_PLUGIN_LIST,
     STS_JAR_URL,
 )
 from localstack.runtime import hooks
@@ -47,7 +50,7 @@ from localstack.utils.files import (
 )
 from localstack.utils.functions import run_safe
 from localstack.utils.http import download
-from localstack.utils.platform import get_arch, is_windows
+from localstack.utils.platform import get_arch, is_mac_os, is_windows
 from localstack.utils.run import run
 from localstack.utils.sync import retry
 from localstack.utils.threads import parallelize
@@ -297,6 +300,33 @@ def install_opensearch(version=None):
                     mkdir(dir_path)
                     chmod_r(dir_path, 0o777)
 
+                # install default plugins for opensearch 1.1+
+                # https://forum.opensearch.org/t/ingest-attachment-cannot-be-installed/6494/12
+                parsed_version = semver.VersionInfo.parse(version)
+                if parsed_version >= "1.1.0":
+                    for plugin in OPENSEARCH_PLUGIN_LIST:
+                        plugin_binary = os.path.join(install_dir, "bin", "opensearch-plugin")
+                        plugin_dir = os.path.join(install_dir, "plugins", plugin)
+                        if not os.path.exists(plugin_dir):
+                            LOG.info("Installing OpenSearch plugin %s", plugin)
+
+                            def try_install():
+                                output = run([plugin_binary, "install", "-b", plugin])
+                                LOG.debug("Plugin installation output: %s", output)
+
+                            # We're occasionally seeing javax.net.ssl.SSLHandshakeException -> add download retries
+                            download_attempts = 3
+                            try:
+                                retry(try_install, retries=download_attempts - 1, sleep=2)
+                            except Exception:
+                                LOG.warning(
+                                    "Unable to download OpenSearch plugin '%s' after %s attempts",
+                                    plugin,
+                                    download_attempts,
+                                )
+                                if not os.environ.get("IGNORE_OS_DOWNLOAD_ERRORS"):
+                                    raise
+
     # patch JVM options file - replace hardcoded heap size settings
     jvm_options_file = os.path.join(install_dir, "config", "jvm.options")
     if os.path.exists(jvm_options_file):
@@ -514,6 +544,14 @@ def install_dynamodb_local():
         tmp_archive = os.path.join(tempfile.gettempdir(), "localstack.ddb.zip")
         download_and_extract_with_retry(DYNAMODB_JAR_URL, tmp_archive, INSTALL_DIR_DDB)
 
+    # download additional libs for Mac M1 (for local dev mode)
+    if is_mac_os() and get_arch() == "arm64":
+        target_path = os.path.join(
+            INSTALL_DIR_DDB, "DynamoDBLocal_lib", "libsqlite4java-osx-aarch64.dylib"
+        )
+        if not file_exists_not_empty(target_path):
+            download(LIBSQLITE_AARCH64_URL, target_path)
+
     # fix logging configuration for DynamoDBLocal
     log4j2_config = """<Configuration status="WARN">
       <Appenders>
