@@ -14,8 +14,8 @@ def acm():
     return Service("acm", listener=AwsApiListener("acm", MotoFallbackDispatcher(provider)))
 
 
-@aws_provider()
-def apigateway():
+@aws_provider(api="apigateway", name="default")
+def apigateway_legacy():
     from localstack.services.apigateway.provider import ApigatewayApiListener, ApigatewayProvider
 
     provider = ApigatewayProvider()
@@ -24,6 +24,16 @@ def apigateway():
     return Service("apigateway", listener=listener, lifecycle_hook=provider)
 
 
+@aws_provider(api="apigateway", name="asf")
+def apigateway_asf():
+    from localstack.services.apigateway.provider_asf import AsfApigatewayProvider
+
+    provider = AsfApigatewayProvider()
+    listener = AwsApiListener("apigateway", MotoFallbackDispatcher(provider))
+
+    return Service("apigateway", listener=listener, lifecycle_hook=provider)
+
+
 @aws_provider()
 def cloudformation():
     from localstack.services.cloudformation.provider import CloudformationProvider
@@ -218,9 +228,9 @@ def route53():
 
 @aws_provider()
 def route53resolver():
-    from localstack.services.route53.provider import Route53ResolverApi
+    from localstack.services.route53resolver.provider import Route53ResolverProvider
 
-    provider = Route53ResolverApi()
+    provider = Route53ResolverProvider()
 
     return Service(
         "route53resolver",
