@@ -1153,7 +1153,7 @@ class SqsProvider(SqsApi, ServiceLifecycleHook):
     ) -> bool:
         redrive_policy = json.loads(queue.attributes.get(QueueAttributeName.RedrivePolicy))
         # TODO: include the names of the dictionary sub - attributes in the autogenerated code?
-        max_receive_count = redrive_policy["maxReceiveCount"]
+        max_receive_count = int(redrive_policy["maxReceiveCount"])
         if std_m.receive_times > max_receive_count:
             dead_letter_target_arn = redrive_policy["deadLetterTargetArn"]
             dl_queue = self._require_queue_by_arn(context, dead_letter_target_arn)
