@@ -5,7 +5,6 @@ import re
 import socket
 import sys
 import threading
-import time
 from functools import lru_cache
 from typing import Dict, Optional, Union
 from urllib.parse import urlparse
@@ -41,8 +40,8 @@ from localstack.utils.aws.aws_models import KinesisStream
 from localstack.utils.collections import pick_attributes
 from localstack.utils.functions import run_safe
 from localstack.utils.http import make_http_request
-from localstack.utils.strings import is_string, is_string_or_bytes, to_str
-from localstack.utils.sync import retry
+from localstack.utils.strings import get_random_hex, is_string, is_string_or_bytes, to_str
+from localstack.utils.sync import poll_condition, retry
 
 # AWS environment variable names
 ENV_ACCESS_KEY = "AWS_ACCESS_KEY_ID"
@@ -930,19 +929,16 @@ def dynamodb_get_item_raw(request):
 
 
 def create_dynamodb_table(
-    table_name,
-    partition_key,
-    env=None,
-    stream_view_type=None,
-    region_name=None,
+    table_name: str,
+    partition_key: str,
+    stream_view_type: str = None,
+    region_name: str = None,
     client=None,
-    sleep_after=2,
+    wait_for_active: bool = True,
 ):
     """Utility method to create a DynamoDB table"""
 
-    dynamodb = client or connect_to_service(
-        "dynamodb", env=env, client=True, region_name=region_name
-    )
+    dynamodb = client or connect_to_service("dynamodb", region_name=region_name)
     stream_spec = {"StreamEnabled": False}
     key_schema = [{"AttributeName": partition_key, "KeyType": "HASH"}]
     attr_defs = [{"AttributeName": partition_key, "AttributeType": "S"}]
@@ -954,21 +950,21 @@ def create_dynamodb_table(
             TableName=table_name,
             KeySchema=key_schema,
             AttributeDefinitions=attr_defs,
-            ProvisionedThroughput={"ReadCapacityUnits": 10, "WriteCapacityUnits": 10},
+            BillingMode="PAY_PER_REQUEST",
             StreamSpecification=stream_spec,
         )
     except Exception as e:
         if "ResourceInUseException" in str(e):
             # Table already exists -> return table reference
-            return connect_to_resource("dynamodb", env=env, region_name=region_name).Table(
-                table_name
-            )
+            return connect_to_resource("dynamodb", region_name=region_name).Table(table_name)
         if "AccessDeniedException" in str(e):
             raise
 
-    if sleep_after:
-        # TODO: do we need this?
-        time.sleep(sleep_after)
+    def _is_active():
+        return dynamodb.describe_table(TableName=table_name)["Table"]["TableStatus"] == "ACTIVE"
+
+    if wait_for_active:
+        poll_condition(_is_active)
 
     return table
 
@@ -1279,3 +1275,21 @@ def await_stack_completion(stack_name, retries=20, sleep=2, statuses=None, regio
 def get_ecr_repository_arn(name, account_id=None, region_name=None):
     pattern = "arn:aws:ecr:%s:%s:repository/%s"
     return _resource_arn(name, pattern, account_id=account_id, region_name=region_name)
+
+
+def get_route53_resolver_firewall_rule_group_arn(
+    id: str, account_id: str = None, region_name: str = None
+):
+    pattern = "arn:aws:route53resolver:%s:%s:firewall-rule-group/%s"
+    return _resource_arn(id, pattern, account_id=account_id, region_name=region_name)
+
+
+def get_route53_resolver_firewall_domain_list_arn(
+    id: str, account_id: str = None, region_name: str = None
+):
+    pattern = "arn:aws:route53resolver:%s:%s:firewall-domain-list/%s"
+    return _resource_arn(id, pattern, account_id=account_id, region_name=region_name)
+
+
+def get_trace_id():
+    return f"1-{get_random_hex(8)}-{get_random_hex(24)}"
